# Contributor's Guide

## Contribution Process

This project is in early alpha, so a more concrete contribution process is still
being developed.

1. Open Github Issue

It's best to create a bug report or feature proposal first before you begin work.
If your contribution request is approved, your PR will be more likey to be accepted.

2. Fork

3. Branch off of master

4. Create pull request against the correct RC branch.

If it's not clear which RC branch to PR against, just ask a maintainer.

## Coding and Documentation Standards

**Style:** [PEP8 Style Guide](https://www.python.org/dev/peps/pep-0008/)

**Docstrings**: [PEP257 Docstring Guide](https://www.python.org/dev/peps/pep-0257)

## Test Coverage
Your code must have significant test coverage in order to be accepted.
